Welcome to pymbolic!
====================

.. automodule:: pymbolic

Pymbolic around the web
-----------------------

* `download <http://pypi.python.org/pypi/pymbolic>`_ (via the package index)
* `documentation <http://documen.tician.de/pymbolic>`_
* `source code via git <http://github.com/inducer/pymbolic>`_ (also bug tracker)

Contents
--------

.. toctree::
   :maxdepth: 2

   primitives
   mappers
   utilities
   algorithms
   geometric-algebra
   misc

* :ref:`genindex`
* :ref:`modindex`

.. vim: sw=4
